package com.cardiff.sytest;

import com.cardiff.client_project.mapper.NurseMapper;
import com.cardiff.client_project.pojo.entity.Nurse;
import com.cardiff.client_project.pojo.vo.NurseVO;
import com.cardiff.client_project.service.imp.NurseServiceImp;
import com.cardiff.client_project.utils.Result;
import org.junit.jupiter.api.Test;
import java.lang.reflect.Field;
import java.util.List;
import static org.junit.jupiter.api.Assertions.*;

public class SimpleUnitTests {

    private void injectMockMapper(NurseServiceImp service, NurseMapper mockMapper) {
        try {
            Field field = NurseServiceImp.class.getDeclaredField("nurseMapper");
            field.setAccessible(true); // 允许访问私有字段
            field.set(service, mockMapper); // 注入模拟对象
        } catch (Exception e) {
            throw new RuntimeException("注入Mock Mapper失败", e);
        }
    }

    @Test
    //测试状态转换
    void testActiveStatusConversion() {
        // 创建服务实例
        NurseServiceImp service = new NurseServiceImp();

        // 创建模拟Mapper
        NurseMapper mockMapper = new NurseMapper() {
            @Override
            public List<Nurse> selectAllNurse(int hospitalId) {
                Nurse nurse = new Nurse();
                nurse.setStatus(1); // ACTIVE状态
                return List.of(nurse);
            }

            // 其他方法空实现
            @Override public Result insertNurseInform(Nurse nurse) { return null; }
            @Override public int[] deleteByIdAndType(List<Integer> ids, String type) { return null; }
        };

        // 通过反射注入
        injectMockMapper(service, mockMapper);

        // 执行测试
        Result result = service.selectAllNurse(1);
        List<NurseVO> nurses = (List<NurseVO>) result.getData();

        // 验证
        assertEquals("ACTIVE", nurses.get(0).getStatus_str());
    }

    @Test
    //测试重复邮箱
    void testDuplicateEmailDetection() {
        NurseServiceImp service = new NurseServiceImp();

        injectMockMapper(service, new NurseMapper() {
            @Override
            public Result insertNurseInform(Nurse nurse) {
                return Result.error("账号已存在");
            }
        });

        Nurse nurse = new Nurse();
        nurse.setEmail("exists@test.com");
        Result result = service.insertNurse(nurse);
        assertEquals("账号已存在", result.getMsg());
    }

    @Test
    // 验证护士信息更新后，数据库中的年龄字段是否被正确修改
    void testUpdateNurseInfo() {

        NurseServiceImp service = new NurseServiceImp();

        //创建模拟Mapper（伪造数据库）
        NurseMapper mockMapper = new NurseMapper() {
            @Override
            public int update(Nurse nurse) {
                // 验证传入的年龄是否是测试值
                if (nurse.getAge() == 30) {
                    return 1; // 返回1表示更新成功
                }
                return 0; // 其他情况返回失败
            }

            @Override public List<Nurse> selectAllNurse(int id) { return null; }
        };

        //通过反射注入模拟Mapper
        injectMockMapper(service, mockMapper);

        Nurse nurseToUpdate = new Nurse();
        nurseToUpdate.setId(1001);      // 设置护士ID
        nurseToUpdate.setAge(30);       // 修改年龄为30岁

        // 更新验证
        Result result = service.update(nurseToUpdate);
        assertEquals(1, result.getCode()); // 检查返回码是否为1（成功）
    }



}